@@ -48,6 +48,7 @@ class SemiSortedTextRefsDict:
         o  __init__(self, textrefclass=TextRefDefault)
         o  add(self, textref, data)
         o  improved_str(self)
+        o  is_empty(self)
     """
     def __init__(self,
                  textrefclass=TextRefDefault):
@@ -62,6 +63,16 @@ class SemiSortedTextRefsDict:
         self.textref2data = dict()
         self.sorted_textrefs = textrefclass(force_validity=True)
 
+    def __iter__(self):
+        """
+            SemiSortedTextRefsDict.__iter__()
+            ___________________________________________________________________
+
+            This method yields TextRef* objects stored self.sorted_textrefs
+        """
+        for obj in self.sorted_textrefs:
+            yield obj
+
     def add(self,
             textref,
             data):
@@ -80,6 +91,18 @@ class SemiSortedTextRefsDict:
 
             RETURNED VALUE: (bool)success
         """
+        if not hasattr(textref, "errors"):
+            # (pimydoc)error::TEXTREF-ERRORID005
+            # ⋅ SemiSortedTextRefsDict.add() got an argument for the <textref> argument
+            # ⋅ but this object doesn't seem to be a TextRef* like object.
+            error = MusaMusaError()
+            error.msgid = "TEXTREF-ERRORID005"
+            error.msg = "SemiSortedTextRefsDict.add() got an argument for <textref> " \
+                "but this object doesn't seem to be a TextRef* like object. " \
+                f"textref='{textref}' (type={type(textref)})  ."
+            self.errors.append(error)
+            return False
+
         if not self.errors.zero_error_or_warning():
             # (pimydoc)error::TEXTREF-ERRORID002
             # ⋅ You can't use SemiSortedTextRefsDict.add() with SemiSortedTextRefsDict object
@@ -138,3 +161,12 @@ class SemiSortedTextRefsDict:
                 res.append(f"*  {textref.definition2str()} : {self.textref2data[textref]}")
 
         return "\n".join(res)
+
+    def is_empty(self):
+        """
+            SemiSortedTextRefsDict.is_empty()
+            ___________________________________________________________________
+
+            RETURNED VALUE: (bool) True if no TextRef stored in self.textref2data
+        """
+        return len(self.textref2data) == 0
