@@ -26,6 +26,9 @@
         TextRefDefault is a general purpose class, allowing to read
    complex strings like "AncientTestament.Genesis.IX.3a"
 
+   Beware ! TextRef* classes don't store the source string you may used to initialize
+            such an object. You have to store this source string apart.
+
 
    Unit testing: see tests/textrefdefault.py
 
